require("chartdirector")

class ColorvlinearmeterController < ApplicationController

    def index()
        @title = "Color Vertical Linear Meters"
        @ctrl_file = File.expand_path(__FILE__)
        @noOfCharts = 6
        render :template => "templates/chartview"
    end

    #
    # Render and deliver the chart
    #
    def getchart()
        # This script can draw different charts depending on the chartIndex
        chartIndex = (params["img"]).to_i

        # The value to display on the meter
        value = 74.25

        # The background and border colors of the meters
        bgColor = [0xbbddff, 0xccffcc, 0xffccff, 0xffffaa, 0xffdddd, 0xeeeeee]
        borderColor = [0x000088, 0x006600, 0x6600aa, 0xee6600, 0x880000, 0x666666]

        # Create a LinearMeter object of size 70 x 260 pixels with a 3-pixel thick rounded frame
        m = ChartDirector::LinearMeter.new(70, 260, bgColor[chartIndex], borderColor[chartIndex])
        m.setRoundedFrame(ChartDirector::Transparent)
        m.setThickFrame(3)

        # Set the scale region top-left corner at (28, 30), with size of 20 x 200 pixels. The scale
        # labels are located on the left (default - implies vertical meter)
        m.setMeter(28, 30, 20, 200)

        # Set meter scale from 0 - 100, with a tick every 10 units
        m.setScale(0, 100, 10)

        # Demostrate different types of color scales and putting them at different positions
        smoothColorScale = [0, 0x6666ff, 25, 0x00bbbb, 50, 0x00ff00, 75, 0xffff00, 100, 0xff0000]
        stepColorScale = [0, 0x33ff33, 50, 0xffff33, 80, 0xff3333, 100]
        highLowColorScale = [0, 0x6666ff, 70, ChartDirector::Transparent, 100, 0xff0000]

        if chartIndex == 0
            # Add the smooth color scale at the default position
            m.addColorScale(smoothColorScale)
        elsif chartIndex == 1
            # Add the step color scale at the default position
            m.addColorScale(stepColorScale)
        elsif chartIndex == 2
            # Add the high low scale at the default position
            m.addColorScale(highLowColorScale)
        elsif chartIndex == 3
            # Add the smooth color scale starting at x = 28 (left of scale) with zero width and
            # ending at x = 28 with 20 pixels width
            m.addColorScale(smoothColorScale, 28, 0, 28, 20)
        elsif chartIndex == 4
            # Add the smooth color scale starting at x = 38 (center of scale) with zero width and
            # ending at x = 28 with 20 pixels width
            m.addColorScale(smoothColorScale, 38, 0, 28, 20)
        else
            # Add the smooth color scale starting at x = 48 (right of scale) with zero width and
            # ending at x = 28 with 20 pixels width
            m.addColorScale(smoothColorScale, 48, 0, 28, 20)
        end

        # Add a blue (0x0000cc) pointer at the specified value
        m.addPointer(value, 0x0000cc)

        # Add a title using white (0xffffff) 8pt Arial Bold font with a border color background
        m.addTitle("Temp C", "arialbd.ttf", 8, 0xffffff).setBackground(borderColor[chartIndex])

        # Add a bottom title using white (0xffffff) 8pt Arial Bold font with a border color
        # background to display the value
        m.addTitle2(ChartDirector::Bottom, m.formatValue(value, "2"), "arialbd.ttf", 8, 0xffffff
            ).setBackground(borderColor[chartIndex])

        # Output the chart
        send_data(m.makeChart2(ChartDirector::PNG), :type => "image/png", :disposition => "inline")

    end

end
